/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.colors;

/**
 * All modern browsers support the following 140 color names.
 * 
 * @author Andrea "Stock" Stocchero
 * 
 * @see <a href="https://www.w3schools.com/colors/colors_names.asp">HTML Color names</a>
 *
 */
public enum HtmlColor implements IsColor
{

	/**
	 * HTML color name "AliceBlue" - <span style="background-color:#F0F8FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AliceBlue("#F0F8FF"),
	/**
	 * HTML color name "AntiqueWhite" - <span style="background-color:#FAEBD7; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AntiqueWhite("#FAEBD7"),
	/**
	 * HTML color name "Aqua" - <span style="background-color:#00FFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Aqua("#00FFFF"),
	/**
	 * HTML color name "Aquamarine" - <span style="background-color:#7FFFD4; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Aquamarine("#7FFFD4"),
	/**
	 * HTML color name "Azure" - <span style="background-color:#F0FFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Azure("#F0FFFF"),
	/**
	 * HTML color name "Beige" - <span style="background-color:#F5F5DC; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Beige("#F5F5DC"),
	/**
	 * HTML color name "Bisque" - <span style="background-color:#FFE4C4; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Bisque("#FFE4C4"),
	/**
	 * HTML color name "Black" - <span style="background-color:#000000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Black("#000000"),
	/**
	 * HTML color name "BlanchedAlmond" - <span style="background-color:#FFEBCD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BlanchedAlmond("#FFEBCD"),
	/**
	 * HTML color name "Blue" - <span style="background-color:#0000FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Blue("#0000FF"),
	/**
	 * HTML color name "BlueViolet" - <span style="background-color:#8A2BE2; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BlueViolet("#8A2BE2"),
	/**
	 * HTML color name "Brown" - <span style="background-color:#A52A2A; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Brown("#A52A2A"),
	/**
	 * HTML color name "BurlyWood" - <span style="background-color:#DEB887; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BurlyWood("#DEB887"),
	/**
	 * HTML color name "CadetBlue" - <span style="background-color:#5F9EA0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CadetBlue("#5F9EA0"),
	/**
	 * HTML color name "Chartreuse" - <span style="background-color:#7FFF00; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Chartreuse("#7FFF00"),
	/**
	 * HTML color name "Chocolate" - <span style="background-color:#D2691E; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Chocolate("#D2691E"),
	/**
	 * HTML color name "Coral" - <span style="background-color:#FF7F50; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Coral("#FF7F50"),
	/**
	 * HTML color name "CornflowerBlue" - <span style="background-color:#6495ED; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CornflowerBlue("#6495ED"),
	/**
	 * HTML color name "Cornsilk" - <span style="background-color:#FFF8DC; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Cornsilk("#FFF8DC"),
	/**
	 * HTML color name "Crimson" - <span style="background-color:#DC143C; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Crimson("#DC143C"),
	/**
	 * HTML color name "Cyan" - <span style="background-color:#00FFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Cyan("#00FFFF"),
	/**
	 * HTML color name "DarkBlue" - <span style="background-color:#00008B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkBlue("#00008B"),
	/**
	 * HTML color name "DarkCyan" - <span style="background-color:#008B8B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkCyan("#008B8B"),
	/**
	 * HTML color name "DarkGoldenRod" - <span style="background-color:#B8860B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkGoldenRod("#B8860B"),
	/**
	 * HTML color name "DarkGray" - <span style="background-color:#A9A9A9; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkGray("#A9A9A9"),
	/**
	 * HTML color name "DarkGrey" - <span style="background-color:#A9A9A9; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkGrey("#A9A9A9"),
	/**
	 * HTML color name "DarkGreen" - <span style="background-color:#006400; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkGreen("#006400"),
	/**
	 * HTML color name "DarkKhaki" - <span style="background-color:#BDB76B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkKhaki("#BDB76B"),
	/**
	 * HTML color name "DarkMagenta" - <span style="background-color:#8B008B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkMagenta("#8B008B"),
	/**
	 * HTML color name "DarkOliveGreen" - <span style="background-color:#556B2F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkOliveGreen("#556B2F"),
	/**
	 * HTML color name "DarkOrange" - <span style="background-color:#FF8C00; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkOrange("#FF8C00"),
	/**
	 * HTML color name "DarkOrchid" - <span style="background-color:#9932CC; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkOrchid("#9932CC"),
	/**
	 * HTML color name "DarkRed" - <span style="background-color:#8B0000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkRed("#8B0000"),
	/**
	 * HTML color name "DarkSalmon" - <span style="background-color:#E9967A; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkSalmon("#E9967A"),
	/**
	 * HTML color name "DarkSeaGreen" - <span style="background-color:#8FBC8F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkSeaGreen("#8FBC8F"),
	/**
	 * HTML color name "DarkSlateBlue" - <span style="background-color:#483D8B; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkSlateBlue("#483D8B"),
	/**
	 * HTML color name "DarkSlateGray" - <span style="background-color:#2F4F4F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkSlateGray("#2F4F4F"),
	/**
	 * HTML color name "DarkSlateGrey" - <span style="background-color:#2F4F4F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkSlateGrey("#2F4F4F"),
	/**
	 * HTML color name "DarkTurquoise" - <span style="background-color:#00CED1; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkTurquoise("#00CED1"),
	/**
	 * HTML color name "DarkViolet" - <span style="background-color:#9400D3; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DarkViolet("#9400D3"),
	/**
	 * HTML color name "DeepPink" - <span style="background-color:#FF1493; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DeepPink("#FF1493"),
	/**
	 * HTML color name "DeepSkyBlue" - <span style="background-color:#00BFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DeepSkyBlue("#00BFFF"),
	/**
	 * HTML color name "DimGray" - <span style="background-color:#696969; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DimGray("#696969"),
	/**
	 * HTML color name "DimGrey" - <span style="background-color:#696969; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DimGrey("#696969"),
	/**
	 * HTML color name "DodgerBlue" - <span style="background-color:#1E90FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DodgerBlue("#1E90FF"),
	/**
	 * HTML color name "FireBrick" - <span style="background-color:#B22222; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FireBrick("#B22222"),
	/**
	 * HTML color name "FloralWhite" - <span style="background-color:#FFFAF0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FloralWhite("#FFFAF0"),
	/**
	 * HTML color name "ForestGreen" - <span style="background-color:#228B22; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ForestGreen("#228B22"),
	/**
	 * HTML color name "Fuchsia" - <span style="background-color:#FF00FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Fuchsia("#FF00FF"),
	/**
	 * HTML color name "Gainsboro" - <span style="background-color:#DCDCDC; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Gainsboro("#DCDCDC"),
	/**
	 * HTML color name "GhostWhite" - <span style="background-color:#F8F8FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GhostWhite("#F8F8FF"),
	/**
	 * HTML color name "Gold" - <span style="background-color:#FFD700; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Gold("#FFD700"),
	/**
	 * HTML color name "GoldenRod" - <span style="background-color:#DAA520; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GoldenRod("#DAA520"),
	/**
	 * HTML color name "Gray" - <span style="background-color:#808080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Gray("#808080"),
	/**
	 * HTML color name "Grey" - <span style="background-color:#808080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Grey("#808080"),
	/**
	 * HTML color name "Green" - <span style="background-color:#008000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Green("#008000"),
	/**
	 * HTML color name "GreenYellow" - <span style="background-color:#ADFF2F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GreenYellow("#ADFF2F"),
	/**
	 * HTML color name "HoneyDew" - <span style="background-color:#F0FFF0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HoneyDew("#F0FFF0"),
	/**
	 * HTML color name "HotPink" - <span style="background-color:#FF69B4; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HotPink("#FF69B4"),
	/**
	 * HTML color name "IndianRed" - <span style="background-color:#CD5C5C; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	IndianRed("#CD5C5C"),
	/**
	 * HTML color name "Indigo" - <span style="background-color:#4B0082; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Indigo("#4B0082"),
	/**
	 * HTML color name "Ivory" - <span style="background-color:#FFFFF0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Ivory("#FFFFF0"),
	/**
	 * HTML color name "Khaki" - <span style="background-color:#F0E68C; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Khaki("#F0E68C"),
	/**
	 * HTML color name "Lavender" - <span style="background-color:#E6E6FA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Lavender("#E6E6FA"),
	/**
	 * HTML color name "LavenderBlush" - <span style="background-color:#FFF0F5; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LavenderBlush("#FFF0F5"),
	/**
	 * HTML color name "LawnGreen" - <span style="background-color:#7CFC00; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LawnGreen("#7CFC00"),
	/**
	 * HTML color name "LemonChiffon" - <span style="background-color:#FFFACD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LemonChiffon("#FFFACD"),
	/**
	 * HTML color name "LightBlue" - <span style="background-color:#ADD8E6; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightBlue("#ADD8E6"),
	/**
	 * HTML color name "LightCoral" - <span style="background-color:#F08080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightCoral("#F08080"),
	/**
	 * HTML color name "LightCyan" - <span style="background-color:#E0FFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightCyan("#E0FFFF"),
	/**
	 * HTML color name "LightGoldenRodYellow" - <span style="background-color:#FAFAD2; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightGoldenRodYellow("#FAFAD2"),
	/**
	 * HTML color name "LightGray" - <span style="background-color:#D3D3D3; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightGray("#D3D3D3"),
	/**
	 * HTML color name "LightGrey" - <span style="background-color:#D3D3D3; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightGrey("#D3D3D3"),
	/**
	 * HTML color name "LightGreen" - <span style="background-color:#90EE90; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightGreen("#90EE90"),
	/**
	 * HTML color name "LightPink" - <span style="background-color:#FFB6C1; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightPink("#FFB6C1"),
	/**
	 * HTML color name "LightSalmon" - <span style="background-color:#FFA07A; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSalmon("#FFA07A"),
	/**
	 * HTML color name "LightSeaGreen" - <span style="background-color:#20B2AA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSeaGreen("#20B2AA"),
	/**
	 * HTML color name "LightSkyBlue" - <span style="background-color:#87CEFA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSkyBlue("#87CEFA"),
	/**
	 * HTML color name "LightSlateGray" - <span style="background-color:#778899; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSlateGray("#778899"),
	/**
	 * HTML color name "LightSlateGrey" - <span style="background-color:#778899; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSlateGrey("#778899"),
	/**
	 * HTML color name "LightSteelBlue" - <span style="background-color:#B0C4DE; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightSteelBlue("#B0C4DE"),
	/**
	 * HTML color name "LightYellow" - <span style="background-color:#FFFFE0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LightYellow("#FFFFE0"),
	/**
	 * HTML color name "Lime" - <span style="background-color:#00FF00; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Lime("#00FF00"),
	/**
	 * HTML color name "LimeGreen" - <span style="background-color:#32CD32; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LimeGreen("#32CD32"),
	/**
	 * HTML color name "Linen" - <span style="background-color:#FAF0E6; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Linen("#FAF0E6"),
	/**
	 * HTML color name "Magenta" - <span style="background-color:#FF00FF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Magenta("#FF00FF"),
	/**
	 * HTML color name "Maroon" - <span style="background-color:#800000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Maroon("#800000"),
	/**
	 * HTML color name "MediumAquaMarine" - <span style="background-color:#66CDAA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumAquaMarine("#66CDAA"),
	/**
	 * HTML color name "MediumBlue" - <span style="background-color:#0000CD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumBlue("#0000CD"),
	/**
	 * HTML color name "MediumOrchid" - <span style="background-color:#BA55D3; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumOrchid("#BA55D3"),
	/**
	 * HTML color name "MediumPurple" - <span style="background-color:#9370DB; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumPurple("#9370DB"),
	/**
	 * HTML color name "MediumSeaGreen" - <span style="background-color:#3CB371; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumSeaGreen("#3CB371"),
	/**
	 * HTML color name "MediumSlateBlue" - <span style="background-color:#7B68EE; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumSlateBlue("#7B68EE"),
	/**
	 * HTML color name "MediumSpringGreen" - <span style="background-color:#00FA9A; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumSpringGreen("#00FA9A"),
	/**
	 * HTML color name "MediumTurquoise" - <span style="background-color:#48D1CC; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumTurquoise("#48D1CC"),
	/**
	 * HTML color name "MediumVioletRed" - <span style="background-color:#C71585; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MediumVioletRed("#C71585"),
	/**
	 * HTML color name "MidnightBlue" - <span style="background-color:#191970; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MidnightBlue("#191970"),
	/**
	 * HTML color name "MintCream" - <span style="background-color:#F5FFFA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MintCream("#F5FFFA"),
	/**
	 * HTML color name "MistyRose" - <span style="background-color:#FFE4E1; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MistyRose("#FFE4E1"),
	/**
	 * HTML color name "Moccasin" - <span style="background-color:#FFE4B5; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Moccasin("#FFE4B5"),
	/**
	 * HTML color name "NavajoWhite" - <span style="background-color:#FFDEAD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NavajoWhite("#FFDEAD"),
	/**
	 * HTML color name "Navy" - <span style="background-color:#000080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Navy("#000080"),
	/**
	 * HTML color name "OldLace" - <span style="background-color:#FDF5E6; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OldLace("#FDF5E6"),
	/**
	 * HTML color name "Olive" - <span style="background-color:#808000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Olive("#808000"),
	/**
	 * HTML color name "OliveDrab" - <span style="background-color:#6B8E23; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OliveDrab("#6B8E23"),
	/**
	 * HTML color name "Orange" - <span style="background-color:#FFA500; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Orange("#FFA500"),
	/**
	 * HTML color name "OrangeRed" - <span style="background-color:#FF4500; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OrangeRed("#FF4500"),
	/**
	 * HTML color name "Orchid" - <span style="background-color:#DA70D6; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Orchid("#DA70D6"),
	/**
	 * HTML color name "PaleGoldenRod" - <span style="background-color:#EEE8AA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PaleGoldenRod("#EEE8AA"),
	/**
	 * HTML color name "PaleGreen" - <span style="background-color:#98FB98; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PaleGreen("#98FB98"),
	/**
	 * HTML color name "PaleTurquoise" - <span style="background-color:#AFEEEE; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PaleTurquoise("#AFEEEE"),
	/**
	 * HTML color name "PaleVioletRed" - <span style="background-color:#DB7093; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PaleVioletRed("#DB7093"),
	/**
	 * HTML color name "PapayaWhip" - <span style="background-color:#FFEFD5; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PapayaWhip("#FFEFD5"),
	/**
	 * HTML color name "PeachPuff" - <span style="background-color:#FFDAB9; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PeachPuff("#FFDAB9"),
	/**
	 * HTML color name "Peru" - <span style="background-color:#CD853F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Peru("#CD853F"),
	/**
	 * HTML color name "Pink" - <span style="background-color:#FFC0CB; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Pink("#FFC0CB"),
	/**
	 * HTML color name "Plum" - <span style="background-color:#DDA0DD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Plum("#DDA0DD"),
	/**
	 * HTML color name "PowderBlue" - <span style="background-color:#B0E0E6; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PowderBlue("#B0E0E6"),
	/**
	 * HTML color name "Purple" - <span style="background-color:#800080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Purple("#800080"),
	/**
	 * HTML color name "RebeccaPurple" - <span style="background-color:#663399; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RebeccaPurple("#663399"),
	/**
	 * HTML color name "Red" - <span style="background-color:#FF0000; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Red("#FF0000"),
	/**
	 * HTML color name "RosyBrown" - <span style="background-color:#BC8F8F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RosyBrown("#BC8F8F"),
	/**
	 * HTML color name "RoyalBlue" - <span style="background-color:#4169E1; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RoyalBlue("#4169E1"),
	/**
	 * HTML color name "SaddleBrown" - <span style="background-color:#8B4513; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SaddleBrown("#8B4513"),
	/**
	 * HTML color name "Salmon" - <span style="background-color:#FA8072; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Salmon("#FA8072"),
	/**
	 * HTML color name "SandyBrown" - <span style="background-color:#F4A460; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SandyBrown("#F4A460"),
	/**
	 * HTML color name "SeaGreen" - <span style="background-color:#2E8B57; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SeaGreen("#2E8B57"),
	/**
	 * HTML color name "SeaShell" - <span style="background-color:#FFF5EE; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SeaShell("#FFF5EE"),
	/**
	 * HTML color name "Sienna" - <span style="background-color:#A0522D; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Sienna("#A0522D"),
	/**
	 * HTML color name "Silver" - <span style="background-color:#C0C0C0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Silver("#C0C0C0"),
	/**
	 * HTML color name "SkyBlue" - <span style="background-color:#87CEEB; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SkyBlue("#87CEEB"),
	/**
	 * HTML color name "SlateBlue" - <span style="background-color:#6A5ACD; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SlateBlue("#6A5ACD"),
	/**
	 * HTML color name "SlateGray" - <span style="background-color:#708090; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SlateGray("#708090"),
	/**
	 * HTML color name "SlateGrey" - <span style="background-color:#708090; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SlateGrey("#708090"),
	/**
	 * HTML color name "Snow" - <span style="background-color:#FFFAFA; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Snow("#FFFAFA"),
	/**
	 * HTML color name "SpringGreen" - <span style="background-color:#00FF7F; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SpringGreen("#00FF7F"),
	/**
	 * HTML color name "SteelBlue" - <span style="background-color:#4682B4; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SteelBlue("#4682B4"),
	/**
	 * HTML color name "Tan" - <span style="background-color:#D2B48C; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Tan("#D2B48C"),
	/**
	 * HTML color name "Teal" - <span style="background-color:#008080; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Teal("#008080"),
	/**
	 * HTML color name "Thistle" - <span style="background-color:#D8BFD8; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Thistle("#D8BFD8"),
	/**
	 * HTML color name "Tomato" - <span style="background-color:#FF6347; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Tomato("#FF6347"),
	/**
	 * HTML color name "Turquoise" - <span style="background-color:#40E0D0; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Turquoise("#40E0D0"),
	/**
	 * HTML color name "Violet" - <span style="background-color:#EE82EE; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Violet("#EE82EE"),
	/**
	 * HTML color name "Wheat" - <span style="background-color:#F5DEB3; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Wheat("#F5DEB3"),
	/**
	 * HTML color name "White" - <span style="background-color:#FFFFFF; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	White("#FFFFFF"),
	/**
	 * HTML color name "WhiteSmoke" - <span style="background-color:#F5F5F5; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WhiteSmoke("#F5F5F5"),
	/**
	 * HTML color name "Yellow" - <span style="background-color:#FFFF00; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	Yellow("#FFFF00"),
	/**
	 * HTML color name "YellowGreen" - <span style="background-color:#9ACD32; border-style: solid; border-width:
	 * 1px;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	YellowGreen("#9ACD32");

	// color string representation in hex mode
	private final String hexValue;
	// color instance
	private final IsColor color;

	/**
	 * Creates a color with HEX value.
	 * 
	 * @param hexValue color string representation in hex mode
	 */
	private HtmlColor(String hexValue) {
		this.hexValue = hexValue;
		// checks if the HEX value
		String newHexvalue = hexValue.substring(1);
		// reads colors for RED, GREEN and BLUE
		String redValue = newHexvalue.substring(0, 2);
		int red = Integer.parseInt(redValue, 16);
		String greenValue = newHexvalue.substring(2, 4);
		int green = Integer.parseInt(greenValue, 16);
		String blueValue = newHexvalue.substring(4);
		int blue = Integer.parseInt(blueValue, 16);
		// by default, using HEX format, transparency is 1
		color = new Color(red, green, blue, Color.DEFAULT_ALPHA);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#getRed()
	 */
	@Override
	public int getRed() {
		return color.getRed();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#getGreen()
	 */
	@Override
	public int getGreen() {
		return color.getGreen();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#getBlue()
	 */
	@Override
	public int getBlue() {
		return color.getBlue();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#getAlpha()
	 */
	@Override
	public double getAlpha() {
		return color.getAlpha();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#alpha(double)
	 */
	@Override
	public IsColor alpha(double alpha) {
		return color.alpha(alpha);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#toRGBA()
	 */
	@Override
	public String toRGBA() {
		return color.toRGBA();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#toRGB()
	 */
	@Override
	public String toRGB() {
		return color.toRGB();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.colors.IsColor#toHSLA()
	 */
	@Override
	public String toHSLA() {
		return color.toHSLA();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.colors.IsColor#toHSL()
	 */
	@Override
	public String toHSL() {
		return color.toHSL();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.utils.IsColor#toHex()
	 */
	@Override
	public String toHex() {
		return hexValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.pepstock.charba.client.colors.IsColor#toRGBs()
	 */
	@Override
	public int toRGBs() {
		return color.toRGBs();
	}

}
